@@ -123,12 +123,12 @@ load_supported_modes_finish (MMIfaceModem *self,
                              GAsyncResult *res,
                              GError **error)
 {
-    GArray *combinations = NULL;
-    const gchar *response;
-    gchar **split = NULL;
-    GMatchInfo *match_info;
-    GRegex *r;
-    guint i;
+    GArray                 *combinations = NULL;
+    const gchar            *response;
+    gchar                 **split = NULL;
+    g_autoptr(GMatchInfo)   match_info = NULL;
+    g_autoptr(GRegex)       r = NULL;
+    guint                   i;
 
     response = mm_base_modem_at_command_finish (MM_BASE_MODEM (self), res, error);
     if (!response)
@@ -145,24 +145,18 @@ load_supported_modes_finish (MMIfaceModem *self,
 
     g_regex_match (r, response, 0, &match_info);
     if (g_match_info_matches (match_info)) {
-        gchar *aux;
+        g_autofree gchar *aux = NULL;
 
         aux = mm_get_string_unquoted_from_match_info (match_info, 1);
-        if (aux) {
+        if (aux)
             split = g_strsplit (aux, ",", -1);
-            g_free (aux);
-        }
     }
 
-    g_match_info_free (match_info);
-    g_regex_unref (r);
-
     if (!split) {
         g_set_error (error,
                      MM_CORE_ERROR,
                      MM_CORE_ERROR_FAILED,
                      "%%IPSYS=? response didn't match");
-        g_regex_unref (r);
         return NULL;
     }
 
@@ -1123,11 +1117,12 @@ icera_band_to_mm (const char *icera)
 }
 
 static GSList *
-parse_bands (const gchar *response, guint32 *out_len)
+parse_bands (const gchar *response,
+             guint32     *out_len)
 {
-    GRegex *r;
-    GMatchInfo *info;
-    GSList *bands = NULL;
+    g_autoptr(GRegex)      r = NULL;
+    g_autoptr(GMatchInfo)  info = NULL;
+    GSList                *bands = NULL;
 
     g_return_val_if_fail (out_len != NULL, NULL);
 
@@ -1164,8 +1159,6 @@ parse_bands (const gchar *response, guint32 *out_len)
         g_free (enabled);
         g_match_info_next (info, NULL);
     }
-    g_match_info_free (info);
-    g_regex_unref (r);
 
     return bands;
 }
@@ -1957,15 +1950,21 @@ store_profile_context_free (StoreProfileContext *ctx)
 static gint
 modem_3gpp_profile_manager_store_profile_finish (MMIfaceModem3gppProfileManager  *self,
                                                  GAsyncResult                    *res,
+                                                 gint                            *out_profile_id,
+                                                 MMBearerApnType                 *out_apn_type,
                                                  GError                         **error)
 {
     StoreProfileContext *ctx;
 
     if (!g_task_propagate_boolean (G_TASK (res), error))
-        return MM_3GPP_PROFILE_ID_UNKNOWN;
+        return FALSE;
 
     ctx = g_task_get_task_data (G_TASK (res));
-    return ctx->profile_id;
+    if (out_profile_id)
+        *out_profile_id = ctx->profile_id;
+    if (out_apn_type)
+        *out_apn_type = MM_BEARER_APN_TYPE_NONE;
+    return TRUE;
 }
 
 static void profile_manager_store_profile_auth_settings (GTask *task);
@@ -2079,7 +2078,7 @@ profile_manager_parent_store_profile_ready (MMIfaceModem3gppProfileManager *self
 {
     GError *error = NULL;
 
-    if (iface_modem_3gpp_profile_manager_parent->store_profile_finish (self, res, &error) == MM_3GPP_PROFILE_ID_UNKNOWN) {
+    if (!iface_modem_3gpp_profile_manager_parent->store_profile_finish (self, res, NULL, NULL, &error)) {
         g_task_return_error (task, error);
         g_object_unref (task);
         return;
@@ -2091,12 +2090,15 @@ profile_manager_parent_store_profile_ready (MMIfaceModem3gppProfileManager *self
 static void
 modem_3gpp_profile_manager_store_profile (MMIfaceModem3gppProfileManager  *self,
                                           MM3gppProfile                   *profile,
+                                          const gchar                     *index_field,
                                           GAsyncReadyCallback              callback,
                                           gpointer                         user_data)
 {
     StoreProfileContext *ctx;
     GTask               *task;
 
+    g_assert (g_strcmp0 (index_field, "profile-id") == 0);
+
     task = g_task_new (self, NULL, callback, user_data);
     ctx = g_slice_new0 (StoreProfileContext);
     ctx->profile = g_object_ref (profile);
@@ -2107,6 +2109,7 @@ modem_3gpp_profile_manager_store_profile (MMIfaceModem3gppProfileManager  *self,
     iface_modem_3gpp_profile_manager_parent->store_profile (
         self,
         profile,
+        index_field,
         (GAsyncReadyCallback)profile_manager_parent_store_profile_ready,
         task);
 }
